@@ -1,10 +1,11 @@
 use anyhow::Result;
 use clap::ArgMatches;
+use prs_lib::Store;
 use thiserror::Error;
 
-use prs_lib::Store;
-
 use crate::cmd::matcher::{recipients::RecipientsMatcher, MainMatcher, Matcher};
+#[cfg(all(feature = "tomb", target_os = "linux"))]
+use crate::util::tomb;
 
 /// A recipients list action.
 pub struct List<'a> {
@@ -24,8 +25,18 @@ impl<'a> List<'a> {
         let matcher_recipients = RecipientsMatcher::with(self.cmd_matches).unwrap();
 
         let store = Store::open(matcher_recipients.store()).map_err(Err::Store)?;
+        #[cfg(all(feature = "tomb", target_os = "linux"))]
+        let mut tomb = store.tomb(
+            !matcher_main.verbose(),
+            matcher_main.verbose(),
+            matcher_main.force(),
+        );
         let recipients = store.recipients().map_err(Err::List)?;
 
+        // Prepare tomb
+        #[cfg(all(feature = "tomb", target_os = "linux"))]
+        tomb::prepare_tomb(&mut tomb, &matcher_main).map_err(Err::Tomb)?;
+
         recipients
             .keys()
             .iter()
@@ -38,6 +49,10 @@ impl<'a> List<'a> {
             })
             .for_each(|key| println!("{}", key,));
 
+        // Finalize tomb
+        #[cfg(all(feature = "tomb", target_os = "linux"))]
+        tomb::finalize_tomb(&mut tomb, &matcher_main, false).map_err(Err::Tomb)?;
+
         Ok(())
     }
 }
@@ -47,6 +62,10 @@ pub enum Err {
     #[error("failed to access password store")]
     Store(#[source] anyhow::Error),
 
+    #[cfg(all(feature = "tomb", target_os = "linux"))]
+    #[error("failed to prepare password store tomb for usage")]
+    Tomb(#[source] anyhow::Error),
+
     #[error("failed to list store recipients")]
     List(#[source] anyhow::Error),
 }
