@@ -148,30 +148,30 @@ impl Shell {
         }
     }
 
-    /// Generate completion script.
-    pub fn generate_to<S, T>(self, app: &mut App<'_>, bin_name: S, out_dir: T)
-    where
-        S: Into<String>,
-        T: Into<std::ffi::OsString>,
-    {
-        match self {
-            Shell::Bash => {
-                clap_generate::generate_to::<generators::Bash, _, _>(app, bin_name, out_dir)
-            }
-            Shell::Elvish => {
-                clap_generate::generate_to::<generators::Elvish, _, _>(app, bin_name, out_dir)
-            }
-            Shell::Fish => {
-                clap_generate::generate_to::<generators::Fish, _, _>(app, bin_name, out_dir)
-            }
-            Shell::PowerShell => {
-                clap_generate::generate_to::<generators::PowerShell, _, _>(app, bin_name, out_dir)
-            }
-            Shell::Zsh => {
-                clap_generate::generate_to::<generators::Zsh, _, _>(app, bin_name, out_dir)
-            }
-        }
-    }
+    // /// Generate completion script.
+    // pub fn generate_to<S, T>(self, app: &mut App<'_>, bin_name: S, out_dir: T)
+    // where
+    //     S: Into<String>,
+    //     T: Into<std::ffi::OsString>,
+    // {
+    //     match self {
+    //         Shell::Bash => {
+    //             clap_generate::generate_to::<generators::Bash, _, _>(app, bin_name, out_dir)
+    //         }
+    //         Shell::Elvish => {
+    //             clap_generate::generate_to::<generators::Elvish, _, _>(app, bin_name, out_dir)
+    //         }
+    //         Shell::Fish => {
+    //             clap_generate::generate_to::<generators::Fish, _, _>(app, bin_name, out_dir)
+    //         }
+    //         Shell::PowerShell => {
+    //             clap_generate::generate_to::<generators::PowerShell, _, _>(app, bin_name, out_dir)
+    //         }
+    //         Shell::Zsh => {
+    //             clap_generate::generate_to::<generators::Zsh, _, _>(app, bin_name, out_dir)
+    //         }
+    //     }
+    // }
 }
 
 impl fmt::Display for Shell {
