@@ -1,6 +1,6 @@
 use clap::App;
 
-use crate::cmd::arg::{ArgStore, CmdArg};
+use crate::cmd::arg::{ArgAllowDirty, ArgNoSync, ArgStore, CmdArg};
 
 /// The init command definition.
 pub struct CmdInit;
@@ -11,5 +11,7 @@ impl CmdInit {
             .alias("initialize")
             .about("Initialize new password store")
             .arg(ArgStore::build())
+            .arg(ArgAllowDirty::build())
+            .arg(ArgNoSync::build())
     }
 }
